@@ -25,6 +25,8 @@ from cStringIO import StringIO
 from xml.dom import minidom
 from distutils import dir_util
 from selenium.webdriver.common.proxy import Proxy, ProxyType
+from selenium.common.exceptions import WebDriverException
+
 
 WEBDRIVER_EXT = "webdriver.xpi"
 EXTENSION_NAME = "fxdriver@googlecode.com"
@@ -57,6 +59,7 @@ class FirefoxProfile(object):
         "browser.safebrowsing.malware.enabled": "false",
         "startup.homepage_welcome_url": "\"about:blank\"",
         "devtools.errorconsole.enabled": "true",
+        "focusmanager.testmode": "true",
         "dom.disable_open_during_load": "false",
         "extensions.autoDisableScopes" : 10,
         "extensions.logging.enabled": "true",
@@ -88,6 +91,7 @@ class FirefoxProfile(object):
         "browser.dom.window.dump.enabled": "true",
         "webdriver_accept_untrusted_certs": "true",
         "webdriver_enable_native_events": native_events,
+        "webdriver_assume_untrusted_issuer": "true",
         "dom.max_script_run_time": "30",
         }
 
@@ -160,25 +164,42 @@ class FirefoxProfile(object):
         """
         Sets the port that WebDriver will be running on
         """
+        if not isinstance(port, int):
+            raise WebDriverException("Port needs to be an integer")
         self._port = port
-        self.default_preferences["webdriver_firefox_port"] =  str(self._port)
+        self.set_preference("webdriver_firefox_port", self._port)
 
     @property
     def accept_untrusted_certs(self):
-        return bool(
+        return self._santise_pref(
             self.default_preferences["webdriver_accept_untrusted_certs"])
 
     @accept_untrusted_certs.setter
     def accept_untrusted_certs(self, value):
-        self.default_preferences["webdriver_accept_untrusted_certs"] = str(value)
+        if value not in [True, False]:
+            raise WebDriverException("Please pass in a Boolean to this call")
+        self.set_preference("webdriver_accept_untrusted_certs", value)
+
+    @property
+    def assume_untrusted_cert_issuer(self):
+        return self._santise_pref(self.default_preferences["webdriver_assume_untrusted_issuer"])
+
+    @assume_untrusted_cert_issuer.setter
+    def assume_untrusted_cert_issuer(self, value):
+        if value not in [True, False]:
+            raise WebDriverException("Please pass in a Boolean to this call")
+
+        self.set_preference("webdriver_assume_untrusted_issuer", value)
 
     @property
     def native_events_enabled(self):
-        return bool(self.default_preferences['webdriver_enable_native_events'])
+        return self._santise_pref(self.default_preferences['webdriver_enable_native_events'])
 
     @native_events_enabled.setter
     def native_events_enabled(self, value):
-        self.default_preferences['webdriver_enable_native_events'] = str(value)
+        if value not in [True, False]:
+            raise WebDriverException("Please pass in a Boolean to this call")
+        self.set_preference("webdriver_enable_native_events", value)
 
     @property
     def encoded(self):
@@ -214,7 +235,13 @@ class FirefoxProfile(object):
             self.set_preference("network.proxy.autoconfig_url", proxy.proxy_autoconfig_url)
 
     #Private Methods
-
+    def _santise_pref(self, item):
+        if item == 'true':
+            return True
+        elif item == 'false':
+            return False
+        else:
+            return item
     def _set_manual_proxy_preference(self, key, setting):
         if setting is None or setting is '':
             return
