@@ -553,8 +553,8 @@ for before they are aborted and a |Timeout| error is returned to the \
 client.''').
       AddJsonParameter('type', '{string}',
 					   'The type of operation to set the timeout for. Valid \
-values are: "script" for script timeouts and "implicit" for modifying the \
-implicit wait timeout.').
+values are: "script" for script timeouts, "implicit" for modifying the \
+implicit wait timeout and "page load" for setting a page load timeout.').
       AddJsonParameter('ms', '{number}',
                        'The amount of time, in milliseconds, that time-limited'
                        ' commands are permitted to run.'))
@@ -726,7 +726,7 @@ Note that this is a platform-independent method of activating IME
       Post('''Change focus to another frame on the page. If the frame ID is \
 `null`, the server
 should switch to the page's default content.''').
-      AddJsonParameter('id', '{string|number|null}',
+      AddJsonParameter('id', '{string|number|null|WebElement JSON Object}',
                        'Identifier for the frame to change focus to.').
       AddError('NoSuchFrame', 'If the frame specified by `id` cannot be found.'))
 
@@ -763,6 +763,11 @@ relative to the upper left corner of the screen.').
       SetReturnType('{x: number, y: number}', 'The X and Y coordinates for the window, \
 relative to the upper left corner of the screen.').
       AddError('NoSuchWindow', 'If the specified window cannot be found.'))
+      
+  resources.append(
+      SessionResource('/session/:sessionId/window/:windowHandle/maximize').
+      Post('''Maximize the currently selected window if not already maximized.''').
+      AddError('NoSuchWindow', 'If the specified window cannot be found.'))
 
   resources.append(
       SessionResource('/session/:sessionId/cookie').
@@ -1252,18 +1257,18 @@ location for correctly generating native events.''').
            'this command to start scrolling at a particular screen location.').
       AddJsonParameter('element', '{string}', 'ID of the element where the '
                        'scroll starts.').
-      AddJsonParameter('xOffset', '{number}', 'The x offset in pixels to scroll '
+      AddJsonParameter('xoffset', '{number}', 'The x offset in pixels to scroll '
                        'by.').
-      AddJsonParameter('yOffset', '{number}', 'The y offset in pixels to scroll '
+      AddJsonParameter('yoffset', '{number}', 'The y offset in pixels to scroll '
                        'by.'))
   resources.append(
       SessionResource('session/:sessionId/touch/scroll').
       Post('Scroll on the touch screen using finger based motion events. Use '
            'this command if you don\'t care where the scroll starts on the '
            'screen.').
-      AddJsonParameter('xOffset', '{number}', 'The x offset in pixels to scroll'
+      AddJsonParameter('xoffset', '{number}', 'The x offset in pixels to scroll'
                        'by.').
-      AddJsonParameter('yOffset', '{number}', 'The y offset in pixels to scroll'
+      AddJsonParameter('yoffset', '{number}', 'The y offset in pixels to scroll'
                        'by.'))
   resources.append(
       SessionResource('session/:sessionId/touch/doubleclick').
@@ -1281,9 +1286,9 @@ location for correctly generating native events.''').
            'command starts at a particulat screen location.').
       AddJsonParameter('element', '{string}', 'ID of the element where the '
                        'flick starts.').
-      AddJsonParameter('xOffset', '{number}', 'The x offset in pixels to flick '
+      AddJsonParameter('xoffset', '{number}', 'The x offset in pixels to flick '
                        'by.').
-      AddJsonParameter('yOffset', '{number}', 'The y offset in pixels to flick '
+      AddJsonParameter('yoffset', '{number}', 'The y offset in pixels to flick '
                        'by.').
       AddJsonParameter('speed', '{number}', 'The speed in pixels per seconds.'))
   resources.append(
